struct_converter

package
v0.0.0-...-f6a81d2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 25, 2024 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ConvertStructs

func ConvertStructs[Source any, Target any](source *Source, target *Target, tagName string) error

ConvertStructs dynamically converts fields from a source struct to a target struct using pointers. It uses struct field names for matching by default but can also use a specified struct tag for matching.

Types

This section is empty.

Jump to