Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ConvertStructs ¶
ConvertStructs dynamically converts fields from a source struct to a target struct using pointers. It uses struct field names for matching by default but can also use a specified struct tag for matching.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.